@@ -1,6 +1,5 @@
 """Tests to cover the document.py file."""
 
-from test.config import testing_parameters
 import pytest
 import pytabular as p
 import os
@@ -8,7 +7,6 @@ from pytabular import logic_utils
 from test.conftest import TestStorage
 
 
-@pytest.mark.parametrize("model", testing_parameters)
 def test_basic_document_funcionality(model):
     """Tests basic documentation functionality."""
     try:
