@@ -1,10 +1,6 @@
 """Bulk of pytests for `PyMeasure()` class."""
 
-import pytest
-from test.config import testing_parameters
 
-
-@pytest.mark.parametrize("model", testing_parameters)
 def test_create_measure(model):
     """Test Creating Measure."""
     name = "Test Measure"
