@@ -4,11 +4,9 @@ These were designed selfishly for my own uses.
 So seperating out... To one day sunset and remove.
 """
 
-from test.config import testing_parameters, testingtablename
-import pytest
+from test.config import testingtablename
 
 
-@pytest.mark.parametrize("model", testing_parameters)
 def test_backingup_table(model):
     """Tests model.backup_table()."""
     model.backup_table(testingtablename)
@@ -24,7 +22,6 @@ def test_backingup_table(model):
     )
 
 
-@pytest.mark.parametrize("model", testing_parameters)
 def test_revert_table2(model):
     """Tests model.revert_table()."""
     model.revert_table(testingtablename)
